import "Turbine"
import "Turbine.UI"
import "Turbine.UI.Lotro"

scrollWindow=Turbine.UI.Lotro.Window();
scrollWindow:SetSize(710,330);
scrollWindow:SetPosition((Turbine.UI.Display:GetWidth()-scrollWindow:GetWidth())/2,(Turbine.UI.Display:GetHeight()-scrollWindow:GetHeight())/2);
scrollWindow:SetText("Scrollbar Sample");

-- create a caption for our scrollable value
opacityCaption=Turbine.UI.Label();
opacityCaption:SetParent(scrollWindow);
opacityCaption:SetSize(120,20);
opacityCaption:SetPosition(10,45);
opacityCaption:SetText("Opacity");

-- create the opacity scrollbar and initialize it
scrollbar1=Turbine.UI.Lotro.ScrollBar();
scrollbar1:SetParent(scrollWindow);
scrollbar1:SetOrientation(Turbine.UI.Orientation.Horizontal);
scrollbar1:SetPosition(opacityCaption:GetLeft()+opacityCaption:GetWidth()+5,opacityCaption:GetTop()+4);
scrollbar1:SetSize(scrollWindow:GetWidth()-10-scrollbar1:GetLeft(),12); -- set width to window-border-left, 12 pixel height is standard for "Lotro" style horizontal scrollbars
scrollbar1:SetBackColor(Turbine.UI.Color(.1,.1,.2)); -- just to give it a little style
scrollbar1:SetMinimum(10);
scrollbar1:SetMaximum(100); -- we will divide the value by 100 to get our 0-1 scale with 2 decimal places
local initValue=scrollWindow:GetOpacity()*100; -- retrieve the initial value and convert it to our scroll scale
if initValue<10 then initValue=10 end; -- it's good practice to make sure you initialize your control to a valid value based on the min/max values you set
scrollbar1:SetValue(initValue);

-- set the ValueChanged event handler to take an action when our value changes, in this case, change the current window's opacity
scrollbar1.ValueChanged=function()
	scrollWindow:SetOpacity(scrollbar1:GetValue()/100); -- we devide the 0-100 scrollbar scale to get our 0-1 opacity scale with 2 decimal places
end

--************************* the first viewport sample
-- create a caption for our viewport
viewport1Caption=Turbine.UI.Label();
viewport1Caption:SetParent(scrollWindow);
viewport1Caption:SetSize(120,20);
viewport1Caption:SetPosition(10,80);
viewport1Caption:SetText("Viewport 1:");

-- create the viewport control all it needs is size and position as it is simply used to create viewable bounds for our map
viewport1=Turbine.UI.Control();
viewport1:SetParent(scrollWindow);
viewport1:SetSize(200,200);
viewport1:SetPosition(viewport1Caption:GetLeft()+viewport1Caption:GetWidth()+5,viewport1Caption:GetTop());
-- create the map content for our viewport, again, it only needs size and position as it is just a container for the grid of images
viewport1.map=Turbine.UI.Control();
viewport1.map:SetParent(viewport1); -- set the map as a child of the viewport so that it will be bounded by it for drawing purposes
viewport1.map:SetSize(1000,800); -- we'll use a 5x4 grid but this obviously could be expanded, or even set up as a recycled array of controls
viewport1.map:SetPosition(0,0); -- we'll start off in the upper left
-- create the grid of map tiles
mapTiles1={}
local hIndex,vIndex;
for hIndex=1,5 do
	mapTiles1[hIndex]={};
	for vIndex=1,4 do
		mapTiles1[hIndex][vIndex]=Turbine.UI.Control()
		mapTiles1[hIndex][vIndex]:SetParent(viewport1.map);
		mapTiles1[hIndex][vIndex]:SetPosition((hIndex-1)*200,(vIndex-1)*200)
		mapTiles1[hIndex][vIndex]:SetSize(200,200);
	end
end
-- set the tile images to a group of images I happen to know from the misty mountains area...
mapTiles1[1][1]:SetBackground(0x4101db9d);
mapTiles1[1][2]:SetBackground(0x4101db9c);
mapTiles1[1][3]:SetBackground(0x4101db9b);
mapTiles1[1][4]:SetBackground(0x4101db9a);

mapTiles1[2][1]:SetBackground(0x4101dba2);
mapTiles1[2][2]:SetBackground(0x4101dba1);
mapTiles1[2][3]:SetBackground(0x4101dba0);
mapTiles1[2][4]:SetBackground(0x4101db9f);

mapTiles1[3][1]:SetBackground(0x4101dba7);
mapTiles1[3][2]:SetBackground(0x4101dba6);
mapTiles1[3][3]:SetBackground(0x4101dba5);
mapTiles1[3][4]:SetBackground(0x4101dba4);

mapTiles1[4][1]:SetBackground(0x4101dbab);
mapTiles1[4][2]:SetBackground(0x4101dbaa);
mapTiles1[4][3]:SetBackground(0x4101dba9);
mapTiles1[4][4]:SetBackground(0x4101dba8);

mapTiles1[5][1]:SetBackground(0x4101dbaf);
mapTiles1[5][2]:SetBackground(0x4101dbae);
mapTiles1[5][3]:SetBackground(0x4101dbad);
mapTiles1[5][4]:SetBackground(0x4101dbac);

-- create the vertical scrollbar for our viewport
vscroll1=Turbine.UI.Lotro.ScrollBar();
vscroll1:SetParent(scrollWindow);
vscroll1:SetOrientation(Turbine.UI.Orientation.Vertical);
vscroll1:SetPosition(viewport1:GetLeft()+viewport1:GetWidth(),viewport1:GetTop());
vscroll1:SetSize(12,viewport1:GetHeight()); -- set width to 12 since it's a "Lotro" style scrollbar and the height is set to match the control that we will be scrolling
vscroll1:SetBackColor(Turbine.UI.Color(.1,.1,.2)); -- just to give it a little style
vscroll1:SetMinimum(0);
vscroll1:SetMaximum(viewport1.map:GetHeight()-viewport1:GetHeight()); -- we will allow scrolling the height of the map-the viewport height
vscroll1:SetValue(0); -- set the initial value
-- set the ValueChanged event handler to take an action when our value changes, in this case, change the map position relative to the viewport
vscroll1.ValueChanged=function()
	viewport1.map:SetTop(0-vscroll1:GetValue());
end

-- create the horizontal scrollbar for our viewport
hscroll1=Turbine.UI.Lotro.ScrollBar();
hscroll1:SetParent(scrollWindow);
hscroll1:SetOrientation(Turbine.UI.Orientation.Horizontal);
hscroll1:SetPosition(viewport1:GetLeft(),viewport1:GetTop()+viewport1:GetHeight());
hscroll1:SetSize(viewport1:GetWidth(),12);
hscroll1:SetBackColor(Turbine.UI.Color(.1,.1,.2)); -- just to give it a little style
hscroll1:SetMinimum(0);
hscroll1:SetMaximum(viewport1.map:GetWidth()-viewport1:GetWidth()); -- we will allow scrolling the width of the map-the viewport width
hscroll1:SetValue(0); -- set the initial value
-- set the ValueChanged event handler to take an action when our value changes, in this case, change the map position relative to the viewport
hscroll1.ValueChanged=function()
	viewport1.map:SetLeft(0-hscroll1:GetValue());
end

--****************************** the second viewport sample
-- create a caption for our viewport
viewport2Caption=Turbine.UI.Label();
viewport2Caption:SetParent(scrollWindow);
viewport2Caption:SetSize(120,20);
viewport2Caption:SetPosition(355, 80);
viewport2Caption:SetText("Viewport 2:");

-- create the viewport control all it needs is size and position as it is simply used to create viewable bounds for our map
viewport2=Turbine.UI.ListBox();
viewport2:SetParent(scrollWindow);
viewport2:SetSize(200,200);
viewport2:SetPosition(viewport2Caption:GetLeft()+viewport2Caption:GetWidth()+5,viewport2Caption:GetTop());
-- this time we create the map content as rows in the listbox
-- create the grid of map tiles

mapTiles2={}; -- now, if we only wanted to use this as a display, there's really no need to maintain the mapTiles outside of their rows, but it's easier to set/manipulate the background images if we do
local hIndex,vIndex;
for vIndex=1,4 do
	mapTiles2[vIndex]={}; -- note, this time we have to use the vIndex as the first index since the row item gets created first and contains the column items
	local tmpRow=Turbine.UI.Control(); -- we will use a control as a container for each row
	tmpRow:SetParent(viewport2);
	tmpRow:SetSize(1000,200);
	for hIndex=1,5 do
		mapTiles2[vIndex][hIndex]=Turbine.UI.Control()
		mapTiles2[vIndex][hIndex]:SetParent(tmpRow);
		mapTiles2[vIndex][hIndex]:SetPosition((hIndex-1)*200,0)
		mapTiles2[vIndex][hIndex]:SetSize(200,200);
	end
	viewport2:AddItem(tmpRow);
end
-- set the tile images to a group of images I happen to know from the misty mountains area...
mapTiles2[1][1]:SetBackground(0x4101db9d);
mapTiles2[2][1]:SetBackground(0x4101db9c);
mapTiles2[3][1]:SetBackground(0x4101db9b);
mapTiles2[4][1]:SetBackground(0x4101db9a);

mapTiles2[1][2]:SetBackground(0x4101dba2);
mapTiles2[2][2]:SetBackground(0x4101dba1);
mapTiles2[3][2]:SetBackground(0x4101dba0);
mapTiles2[4][2]:SetBackground(0x4101db9f);

mapTiles2[1][3]:SetBackground(0x4101dba7);
mapTiles2[2][3]:SetBackground(0x4101dba6);
mapTiles2[3][3]:SetBackground(0x4101dba5);
mapTiles2[4][3]:SetBackground(0x4101dba4);

mapTiles2[1][4]:SetBackground(0x4101dbab);
mapTiles2[2][4]:SetBackground(0x4101dbaa);
mapTiles2[3][4]:SetBackground(0x4101dba9);
mapTiles2[4][4]:SetBackground(0x4101dba8);

mapTiles2[1][5]:SetBackground(0x4101dbaf);
mapTiles2[2][5]:SetBackground(0x4101dbae);
mapTiles2[3][5]:SetBackground(0x4101dbad);
mapTiles2[4][5]:SetBackground(0x4101dbac);

-- create the vertical scrollbar for our viewport
vscroll2=Turbine.UI.Lotro.ScrollBar();
vscroll2:SetParent(scrollWindow);
vscroll2:SetOrientation(Turbine.UI.Orientation.Vertical);
vscroll2:SetPosition(viewport2:GetLeft()+viewport2:GetWidth(),viewport2:GetTop());
vscroll2:SetSize(12,viewport2:GetHeight()); -- set width to 12 since it's a "Lotro" style scrollbar and the height is set to match the control that we will be scrolling
vscroll2:SetBackColor(Turbine.UI.Color(.1,.1,.2)); -- just to give it a little style
viewport2:SetVerticalScrollBar(vscroll2);
--note the complete lack of setting minimum, maximum values, initializing the value or creating an action.

-- create the horizontal scrollbar for our viewport
hscroll2=Turbine.UI.Lotro.ScrollBar();
hscroll2:SetParent(scrollWindow);
hscroll2:SetOrientation(Turbine.UI.Orientation.Horizontal);
hscroll2:SetPosition(viewport2:GetLeft(),viewport2:GetTop()+viewport2:GetHeight());
hscroll2:SetSize(viewport2:GetWidth(),12);
hscroll2:SetBackColor(Turbine.UI.Color(.1,.1,.2)); -- just to give it a little style
viewport2:SetHorizontalScrollBar(hscroll2);
--note the complete lack of setting minimum, maximum values, initializing the value or creating an action.
hscroll2.ValueChanged=function()
Turbine.Shell.WriteLine("value:"..hscroll2:GetValue())
end

scrollWindow:SetVisible(true);
